@@ -26,11 +26,11 @@ SemiParBIVProbit <- function(formula, data = list(), weights = NULL, subset = NU
              "J0J90","J0J270","J180J90","J180J270",
              "G0G90","G0G270","G180G90","G180G270")  
   
-  opc  <- c("N","C0","C90","C180","C270","J0","J90","J180","J270","G0","G90","G180","G270","F","AMH","FGM","T")
+  opc  <- c("N","C0","C90","C180","C270","J0","J90","J180","J270","G0","G90","G180","G270","F","AMH","FGM","T","PL","HO")
   scc  <- c("C0", "C180", "J0", "J180", "G0", "G180", BivD2)
   sccn <- c("C90", "C270", "J90", "J270", "G90", "G270")
   mb   <- c("B", "BSS", "BPO", "BPO0")
-  m2   <- c("N","N2","GU","rGU","LO","LN","WEI","iG","GA","GAi","BE","FISK")
+  m2   <- c("N","N2","GU","rGU","LO","LN","WEI","iG","GA","BE","FISK")
   m3   <- c("DAGUM","SM")
   m1d  <- c("PO", "ZTP") 
   m2d  <- c("NBI", "NBII","NBIa", "NBIIa", "PIG") 
@@ -38,12 +38,13 @@ SemiParBIVProbit <- function(formula, data = list(), weights = NULL, subset = NU
   M    <- list(m1d = m1d, m2 = m2, m2d = m2d, m3 = m3, BivD = BivD, 
                opc = opc, extra.regI = extra.regI, margins = margins, bl = bl, intf = intf,
                theta.fx = theta.fx, Model = Model, mb = mb, BivD2 = BivD2, dof = dof)  
-  
+    surv.flex <- FALSE
+
   ct  <- data.frame( c(opc),
-                    c(1:14,55,56,57) 
+                    c(1:14,55,56,57,60,61) 
                      )
   cta <- data.frame( c(opc),
-                     c(1,3,23,13,33,6,26,16,36,4,24,14,34,5,55,56,2) 
+                     c(1,3,23,13,33,6,26,16,36,4,24,14,34,5,55,56,2,60,61) 
                      )                   
 if(BivD %in% BivD2){
   
@@ -73,6 +74,7 @@ if(BivD %in% BivD2){
   
  #######################################################################################    
   
+  cl <- match.call()
   mf <- match.call(expand.dots = FALSE)
             
   pred.varR <- pred.var(formula, l.flist) 
@@ -106,7 +108,7 @@ if(BivD %in% BivD2){
                    }
                                       
  
-  if(is.null(weights)) {weights <- rep(1,dim(data)[1]) 
+  if(!("(weights)" %in% names(data))) {weights <- rep(1,dim(data)[1]) 
                         data$weights <- weights
                         names(data)[length(names(data))] <- "(weights)"} else weights <- data[,"(weights)"]    
   
@@ -370,8 +372,24 @@ if(missing(parscale)) parscale <- 1
   my.env <- new.env()
   my.env$signind <- 1
 
+  lsgam1 <- length(gam1$smooth)
+  lsgam2 <- length(gam2$smooth)
+  lsgam3 <- length(gam3$smooth)
+  lsgam4 <- length(gam4$smooth)
+  lsgam5 <- length(gam5$smooth)
+  lsgam6 <- length(gam6$smooth)
+  lsgam7 <- length(gam7$smooth)
+  lsgam8 <- length(gam8$smooth)
 
-  VC <- list(X1 = X1, inde = inde,my.env=my.env,
+  VC <- list(lsgam1 = lsgam1,
+             lsgam2 = lsgam2,
+             lsgam3 = lsgam3,
+             lsgam4 = lsgam4,
+             lsgam5 = lsgam5,
+             lsgam6 = lsgam6,
+             lsgam7 = lsgam7,
+             lsgam8 = lsgam8, 
+             X1 = X1, inde = inde,my.env=my.env,
              X2 = X2, 
              X3 = X3,
              X4 = X4, 
@@ -415,7 +433,7 @@ if(missing(parscale)) parscale <- 1
              Cont = "NO", ccss = "no", m2 = m2, m3 = m3, m2d = m2d, m1d = m1d, m3d = NULL, bl = bl,
              X2s = X2s, X3s = X3s, triv = FALSE, y2m = y2m,
              theta.fx = theta.fx, i.rho = i.rho, 
-             BivD2 = BivD2, cta = cta, ct = ct, zerov = -10) # original n only needed in SemiParBIVProbit.fit
+             BivD2 = BivD2, cta = cta, ct = ct, zerov = -10, surv.flex = surv.flex) # original n only needed in SemiParBIVProbit.fit
              
   if(gc.l == TRUE) gc()           
              
@@ -474,18 +492,21 @@ if(gc.l == TRUE) gc()
   ##########################################################################################################################
 
 
-e.v <- min(eigen(SemiParFit$fit$hessian, symmetric=TRUE, only.values = TRUE)$values)
+e.v <- round(min(eigen(SemiParFit$fit$hessian, symmetric=TRUE, only.values = TRUE)$values), 6)
 gradi <- round(max(abs(SemiParFit$fit$gradient)),1)
 
 me1 <- "Largest absolute gradient value is not close to 0."
 me2 <- "Information matrix is not positive definite."
 me3 <- "Read the WARNINGS section in ?SemiParBIVProbit."
 
-if(gradi > 10 && e.v <= 0){ warning(me1, call. = FALSE); warning(paste(me2,"\n",me3), call. = FALSE)} 
+if(gradi > 10 && e.v < 0){ warning(me1, call. = FALSE); warning(paste(me2,"\n",me3), call. = FALSE)} 
 if(gradi > 10 && e.v > 0)   warning(paste(me1,"\n",me3), call. = FALSE)
-if(gradi < 10 && e.v <= 0)  warning(paste(me2,"\n",me3), call. = FALSE)
+if(gradi < 10 && e.v < 0)  warning(paste(me2,"\n",me3), call. = FALSE)
 
+  ##########################################################################################################################
 
+gam1$call$data <- gam2$call$data <- gam3$call$data <- gam4$call$data <- gam5$call$data <- gam6$call$data <- gam7$call$data <- gam8$call$data <- cl$data 
+  # for all.terms
   ##########################################################################################################################
 
 
@@ -536,13 +557,14 @@ L <- list(fit = SemiParFit$fit, dataset = dataset, formula = formula,
           respvec = respvec, inde = inde, 
           qu.mag = qu.mag, 
           sigma2 = SemiParFit.p$sigma2, sigma2.a = SemiParFit.p$sigma2.a,
-          nu = SemiParFit.p$nu, nu.a = SemiParFit.p$nu.a,
+          nu = SemiParFit.p$nu, nu.a = SemiParFit.p$nu.a, Vb.t = SemiParFit.p$Vb.t,
           gp1 = gp1, gp2 = gp2, gp3 = gp3, gp4 = gp4, gp5 = gp5, gp6 = gp6, gp7 = gp7, gp8 = gp8, 
           X2s = X2s, X3s = X3s, p1n=SemiParFit.p$p1n , p2n = SemiParFit.p$p2n, 
           VC = VC, Model = Model, magpp = SemiParFit$magpp,
           gamlssfit = gamlssfit, Cont = "NO", tau = SemiParFit.p$tau, 
           tau.a = SemiParFit.p$tau.a, l.flist = l.flist, v1 = v1, v2 = v2, triv = FALSE, univar.gamlss = FALSE,
-          gamlss = gamlss2, BivD2 = BivD2, dof = dof, dof.a = dof)
+          gamlss = gamlss2, BivD2 = BivD2, dof = dof, dof.a = dof, call = cl,
+          surv = FALSE, surv.flex = surv.flex)
 
 
 if(BivD %in% BivD2){       
