@@ -8,7 +8,9 @@ pVbres <- postVb(SemiParFit, VC)
 
 He         <- pVbres$He        
 Vb         <- pVbres$Vb        
-HeSh       <- pVbres$HeSh      
+HeSh       <- pVbres$HeSh   
+Vb.t       <- pVbres$Vb.t
+
 F          <- pVbres$F         
 F1         <- pVbres$F1        
 R          <- pVbres$R         
@@ -26,39 +28,39 @@ theta12 <- SemiParFit$fit$theta12
 theta13 <- SemiParFit$fit$theta13     
 theta23 <- SemiParFit$fit$theta23  
 
+if(is.null(VC$X4)){
+
 names(theta12) <- "theta12"
 names(theta13) <- "theta13" 
 names(theta23) <- "theta23" 
 
+}
+
 theta12.a  <- mean(theta12) 
 theta13.a  <- mean(theta13)
 theta23.a  <- mean(theta23)   
 
-# useful for when we will have predictors on correlations if development is feasible
-
 ############################################################################################
 
 
-  if(Model=="TSS"){
+  if(Model %in% c("TSS","TESS")){
 
   SemiParFit$fit$eta2 <- VC$X2s%*%SemiParFit$fit$argument[(VC$X1.d2+1):(VC$X1.d2+VC$X2.d2)]
   SemiParFit$fit$eta3 <- VC$X3s%*%SemiParFit$fit$argument[(VC$X1.d2+VC$X2.d2+1):(VC$X1.d2+VC$X2.d2+VC$X3.d2)]
   
-  p1n <- predict.gam(GAM$gam1, type="response")
+  p1n <- predict.gam(GAM$gam1, type = "response")
   p2n <- probm(VC$X2s%*%coef(GAM$gam2), VC$margins[2])$pr 
   p3n <- probm(VC$X3s%*%coef(GAM$gam3), VC$margins[3])$pr 
  
 }
 
 
-# we potentially need TESS here, check X2s and X3s
-
-
 
 if(VC$gc.l == TRUE) gc()  
 
 
-VC$l.sp4 <- 0 # this will need to be amended if we have predictors on corrs
+if( !(VC$penCor %in% c("unpen") && VC$l.flist == 6) ) VC$l.sp4 <- 0  
+# in the previous version we had VC$l.sp4 <- 0 but with 6 eqs and unpen corrs we need l.sp4 and can't set it to 0 
 
 edf.loopR <- edf.loop(VC, F, F1, GAM)
  
@@ -67,7 +69,7 @@ edf1 <- edf.loopR$edf1
   
 sp <- SemiParFit$sp 
   
-                 list(SemiParFit = SemiParFit, He = He, logLik = logLik, Vb = Vb, 
+                 list(SemiParFit = SemiParFit, He = He, logLik = logLik, Vb = Vb, Vb.t = Vb.t,
                       HeSh = HeSh, F = F, F1 = F1, t.edf = t.edf, edf = edf, 
                       edf11 = edf1,
                       edf1 = edf[[1]], edf2 = edf[[2]], edf3 = edf[[3]], edf4 = edf[[4]], 
