@@ -26,6 +26,27 @@ teta <- -teta
 
 
 
+if(BivD=="HO"){
+
+c.copula.be2 <- (-log(p2))^(1/teta - 1) * ((-log(p1))^(1/teta) + (-log(p2))^(1/teta))^(teta - 
+    1) * exp(-((-log(p1))^(1/teta) + (-log(p2))^(1/teta))^teta)/p2 
+    
+}
+
+
+if(BivD=="PL"){
+
+c.copula.be2 <- (teta - (0.5 * ((2 * ((p1 + p2) * (teta - 1) + 1) - 4 * (p1 * 
+    teta)) * (teta - 1)/sqrt(((p1 + p2) * (teta - 1) + 1)^2 - 
+    4 * (p1 * p2 * teta * (teta - 1)))) + 1))/(2 * (teta - 1)) 
+ 
+
+}
+
+
+
+
+
 if(BivD=="FGM"){
 
 c.copula.be2 <- p1 * (1 + teta * (1 - 2 * p2) * (1 - p1))
