@@ -25,18 +25,19 @@ copulaSampleSel <- function(formula, data = list(), weights = NULL, subset = NUL
   sp6 <- gp6 <- gam6 <- X6 <- NULL  
   sp7 <- gp7 <- gam7 <- X7 <- NULL
   sp8 <- gp8 <- gam8 <- X8 <- NULL     
-  dataset <- NULL
+  dataset <- gamlss <- NULL
   X2s <- X3s <- X4s <- X5s <- X6s <- X7s <- X8s <- NULL 
-  
+    surv.flex <- FALSE
+
     BivD2 <- c("C0C90","C0C270","C180C90","C180C270",
                "J0J90","J0J270","J180J90","J180J270",
-             "G0G90","G0G270","G180G90","G180G270")
+               "G0G90","G0G270","G180G90","G180G270")
   
   
-  opc  <- c("N","C0","C90","C180","C270","J0","J90","J180","J270","G0","G90","G180","G270","F","AMH","FGM","T")
+  opc  <- c("N","C0","C90","C180","C270","J0","J90","J180","J270","G0","G90","G180","G270","F","AMH","FGM","T","PL","HO")
   scc  <- c("C0", "C180", "J0", "J180", "G0", "G180", BivD2)
   sccn <- c("C90", "C270", "J90", "J270", "G90", "G270")
-  m2   <- c("N","N2","GU","rGU","LO","LN","WEI","iG","GA","GAi","BE","FISK")
+  m2   <- c("N","N2","GU","rGU","LO","LN","WEI","iG","GA","BE","FISK")
   m3   <- c("DAGUM","SM")
   m1d  <- c("PO", "ZTP")
   m2d  <- c("NBI", "NBII","NBIa", "NBIIa","PIG")
@@ -46,8 +47,8 @@ copulaSampleSel <- function(formula, data = list(), weights = NULL, subset = NUL
   M    <- list(m1d = m1d, m2 = m2, m2d = m2d, m3 = m3, m3d = m3d, BivD = BivD, 
                opc = opc, extra.regI = extra.regI, margins = margins, bl = bl, dof = dof)
 
-  ct  <- data.frame( c(opc), c(1:14,55,56,57) )
-  cta <- data.frame( c(opc), c(1,3,23,13,33,6,26,16,36,4,24,14,34,5,55,56,2) )                   
+  ct  <- data.frame( c(opc), c(1:14,55,56,57,60,61) )
+  cta <- data.frame( c(opc), c(1,3,23,13,33,6,26,16,36,4,24,14,34,5,55,56,2,60,61) )                   
 
 
 
@@ -81,8 +82,9 @@ copulaSampleSel <- function(formula, data = list(), weights = NULL, subset = NUL
  if(!is.list(formula)) stop("You must specify a list of equations.")
  M$l.flist <- l.flist <- length(formula) 
  pream.wm(formula, margins, M, l.flist, type = "copSS")
- form.check(formula, l.flist) 
-
+ form.check(formula, l.flist)
+ 
+  cl <- match.call()
   mf <- match.call(expand.dots = FALSE)
             
   pred.varR <- pred.var(formula, l.flist) 
@@ -110,7 +112,7 @@ copulaSampleSel <- function(formula, data = list(), weights = NULL, subset = NUL
      data[indS == FALSE, v2[1]] <- 0.01  
      data <- na.omit(data)
 
-  if(is.null(weights)) {weights <- rep(1,dim(data)[1]) 
+  if(!("(weights)" %in% names(data))) {weights <- rep(1,dim(data)[1]) 
                         data$weights <- weights
                         names(data)[length(names(data))] <- "(weights)"} else weights <- data[,"(weights)"]    
   
@@ -124,7 +126,9 @@ copulaSampleSel <- function(formula, data = list(), weights = NULL, subset = NUL
   gam1 <- eval(substitute(gam(formula.eq1, binomial(link = margins[1]), gamma=infl.fac, weights=weights, 
                               data=data),list(weights=weights))) 
 
-  X1 <- model.matrix(gam1)
+  X1 <- model.matrix(gam1) ## this may have to be changed to make it more generic using predict maybe
+                           ## also in other functions in the package but not really needed maybe
+                           ## it depends on the purpose
   X1.d2 <- dim(X1)[2]
   l.sp1 <- length(gam1$sp)
   y1 <- gam1$y
@@ -271,8 +275,25 @@ if(missing(parscale)) parscale <- 1
                   cy1.cy2 = cy1.cy2, 
                   cy1 = cy1,
                   cy = cy, univ = 0)
-  
-  VC <- list(X1 = X1, 
+
+  lsgam1 <- length(gam1$smooth)
+  lsgam2 <- length(gam2$smooth)
+  lsgam3 <- length(gam3$smooth)
+  lsgam4 <- length(gam4$smooth)
+  lsgam5 <- length(gam5$smooth)
+  lsgam6 <- length(gam6$smooth)
+  lsgam7 <- length(gam7$smooth)
+  lsgam8 <- length(gam8$smooth)
+
+  VC <- list(lsgam1 = lsgam1,
+             lsgam2 = lsgam2,
+             lsgam3 = lsgam3,
+             lsgam4 = lsgam4,
+             lsgam5 = lsgam5,
+             lsgam6 = lsgam6,
+             lsgam7 = lsgam7,
+             lsgam8 = lsgam8,
+             X1 = X1, 
              X2 = X2, 
              X3 = X3,
              X4 = X4, 
@@ -317,7 +338,7 @@ if(missing(parscale)) parscale <- 1
              Cont = "NO", ccss = "yes", m2 = m2, m3 = m3, 
              m1d = m1d, m2d = m2d, m3d = m3d, bl = bl, inde = inde,
              X2s = X2s, X3s = X3s, X4s = X4s, X5s = X5s, triv = FALSE, y2m = y2m, zerov = -10,
-             BivD2 = BivD2, cta = cta, ct = ct) 
+             BivD2 = BivD2, cta = cta, ct = ct, surv.flex = surv.flex) 
              
   if(gc.l == TRUE) gc()           
              
@@ -349,19 +370,22 @@ if(missing(parscale)) parscale <- 1
   ##########################################################################################################################
 
 
-e.v <- min(eigen(SemiParFit$fit$hessian, symmetric=TRUE, only.values = TRUE)$values)
+e.v <- round(min(eigen(SemiParFit$fit$hessian, symmetric=TRUE, only.values = TRUE)$values), 6)
 gradi <- round(max(abs(SemiParFit$fit$gradient)),1)
 
 me1 <- "Largest absolute gradient value is not close to 0."
 me2 <- "Information matrix is not positive definite."
 me3 <- "Read the WARNINGS section in ?copulaSampleSel."
 
-if(gradi > 10 && e.v <= 0){ warning(me1, call. = FALSE); warning(paste(me2,"\n",me3), call. = FALSE)} 
+if(gradi > 10 && e.v < 0){ warning(me1, call. = FALSE); warning(paste(me2,"\n",me3), call. = FALSE)} 
 if(gradi > 10 && e.v > 0)   warning(paste(me1,"\n",me3), call. = FALSE)
-if(gradi < 10 && e.v <= 0)  warning(paste(me2,"\n",me3), call. = FALSE)
-
+if(gradi < 10 && e.v < 0)  warning(paste(me2,"\n",me3), call. = FALSE)
 
   ##########################################################################################################################
+gam1$call$data <- gam2$call$data <- gam3$call$data <- gam4$call$data <- gam5$call$data <- gam6$call$data <- gam7$call$data <- gam8$call$data <- cl$data 
+  # for all.terms
+  ##########################################################################################################################
+
 
 L <- list(fit = SemiParFit$fit, dataset = dataset, formula = formula,
           gam1 = gam1, gam2 = gam2, gam3 = gam3, gam4 = gam4, gam5 = gam5, 
@@ -373,7 +397,7 @@ L <- list(fit = SemiParFit$fit, dataset = dataset, formula = formula,
           l.sp4 = l.sp4, l.sp5 = l.sp5, l.sp6 = l.sp6,
           l.sp7 = l.sp7, l.sp8 = l.sp8, bl = bl,
           fp = fp,  
-          iter.if = SemiParFit$iter.if, iter.inner = SemiParFit$iter.inner,
+          iter.if = SemiParFit$iter.if, iter.inner = SemiParFit$iter.inner,Vb.t = SemiParFit.p$Vb.t,
           theta = SemiParFit.p$theta, 
           theta.a = SemiParFit.p$theta.a,
           OR = SemiParFit.p$OR, 
@@ -414,7 +438,8 @@ L <- list(fit = SemiParFit$fit, dataset = dataset, formula = formula,
           p1n=SemiParFit.p$p1n , p2n = SemiParFit.p$p2n, 
           VC = VC, Model = NULL, magpp = SemiParFit$magpp,
           gamlss = gamlss, Cont = "NO", tau = SemiParFit.p$tau, tau.a = SemiParFit.p$tau.a, 
-          l.flist = l.flist, v1 = v1, v2 = v2, triv = FALSE, univar.gamlss = FALSE, BivD2 = BivD2, dof = dof, dof.a = dof)
+          l.flist = l.flist, v1 = v1, v2 = v2, triv = FALSE, univar.gamlss = FALSE, BivD2 = BivD2, dof = dof, dof.a = dof, call = cl,
+          surv = FALSE, surv.flex = surv.flex)
 
 class(L) <- c("copulaSampleSel", "SemiParBIVProbit")
 
