@@ -2,7 +2,7 @@ summary.copulaReg <- function(object, n.sim = 100, prob.lev = 0.05, ...){
 
   bs <- SE <- Vb <- epds <- sigma2.st <- sigma2 <- nu.st <- nu <- est.RHOb <- XX <- Xt <- V <- 1 
   
-  cont1par  <- c(object$VC$m1d)   
+  cont1par  <- c(object$VC$m1d,object$VC$bl)   
   cont2par  <- c(object$VC$m2,object$VC$m2d) 
   cont3par  <- c(object$VC$m3,object$VC$m3d) 
   n <- object$n  
@@ -63,7 +63,8 @@ rm(bs, SE, Vb, XX, Xt, V)
               l.sp1 = object$l.sp1, l.sp2 = object$l.sp2, l.sp3 = object$l.sp3, 
               l.sp4 = object$l.sp4, l.sp5 = object$l.sp5, l.sp6 = object$l.sp6, 
               l.sp7 = object$l.sp7, l.sp8 = object$l.sp8,
-              X3.null = is.null(object$X3), univar.gamlss = FALSE, m2 = object$VC$m2, m3 = object$VC$m3 )
+              X3.null = is.null(object$X3), univar.gamlss = FALSE, m2 = object$VC$m2, m3 = object$VC$m3, surv = object$surv,
+              surv.flex = object$surv.flex)
               
               
               
